@@ -3,7 +3,7 @@
    **  Email X-Header
    **
    **  By Pontus Ullgren <pontus.ullgren@addin.se>
-   **  (c) 2001 (GNU GPL - see ../../COPYING)
+   **  (c) 2003 (GNU GPL - see ../../COPYING)
    **
    **  This plugin lets site operators add one or more 
    **  X-header fields in all emails sent using their 
@@ -21,38 +21,35 @@
  **   The example headers add the version of X-Header 
  **   and the logged in users HTTP_USER_AGENT
  *******************************************************/
-
+global $xheader;
 $xheader = Array ( "X-XheaderVersion" => "1.1",
-	"X-UserAgent"=>"$GLOBALS[HTTP_USER_AGENT]");
+	"X-UserAgent"=>$GLOBALS['HTTP_USER_AGENT']);
 
 
 /*******************************************************
  **   No need to change anything else below this point.
  *******************************************************/
-
-
-
-global $email_headers;
-$email_headers = $xheader;
-
 function squirrelmail_plugin_init_xheader()
 {
     global $squirrelmail_plugin_hooks;
 
-    $squirrelmail_plugin_hooks['smtp_send']['xheader']
+    $squirrelmail_plugin_hooks['compose_send']['xheader']
             = 'xheader_addition';
 } // end squirrelmail_plugin_init_xheader()
 
 
-function xheader_addition()
+function xheader_addition(&$argv)
 {
+  global $xheader;
 
-    global $email_headers, $more_headers;
+  // Get the arguments
+  $hookName = &$argv[0];
+  $message = &$argv[1];
 
-    while(list($key, $value) = each($email_headers))
-    {
-          $more_headers[$key] = $value;
-    }
+  while(list($key, $value) = each($xheader))
+  { 
+    $message->rfc822_header->more_headers[$key] = $value;
+  }
 } // end xheader_addition()
 
 ?>
